@@ -4,10 +4,10 @@
 # the conversion is in progress.
 # Author: Louis Bertrand, based on original by Tony DiCola
 
+# A 4.7Kohm pullup between DATA and POWER is REQUIRED!
+
 import time
-
 import board
-
 from adafruit_onewire.bus import OneWireBus
 from adafruit_ds18x20 import DS18X20
 
@@ -27,5 +27,5 @@ while True:
     while time.monotonic() < conversion_ready_at:
         print(".", end="")
         time.sleep(0.1)
-    print('\nTemperature: {0:0.3f}C\n'.format(ds18.read_temperature()))
+    print("\nTemperature: {0:0.3f}C\n".format(ds18.read_temperature()))
     time.sleep(1.0)
